diff_trees

Function diff_trees 

pub fn diff_trees(
    base: &Value,
    next: &Value,
) -> (Vec<Value>, Vec<Value>, Option<Vec<Value>>, bool)
Report what changed, what was removed, the root list when it can no longer be inherited, and whether the cursor moved.