SemanticValueObservation

Enum SemanticValueObservation 

pub enum SemanticValueObservation {
    Known {
        value: String,
        sensitivity: SemanticValueSensitivity,
        evidence: EvidenceProvenance,
    },
    Absent {
        reason: String,
        evidence: EvidenceProvenance,
    },
    Unknown {
        reason: String,
    },
    Unsupported {
        capability: String,
        reason: String,
    },
    Withheld {
        reason: String,
        sensitivity: SemanticValueSensitivity,
    },
}
A semantic value with absence, support and confidentiality preserved.

Variants



Known

The value is known for this committed revision.

Fields

value: String

Exact plaintext value.

sensitivity: SemanticValueSensitivity

Application-declared artifact sensitivity.

evidence: EvidenceProvenance

Source proving this value for the committed revision.



Absent

The node authoritatively has no value now.

Fields

reason: String

Why the node currently has no semantic value.

evidence: EvidenceProvenance

Authoritative source proving absence.



Unknown

A later paired revision may provide the value.

Fields

reason: String

Retryable revision-domain reason.



Unsupported

The frozen contract cannot provide semantic values.

Fields

capability: String

Always semantic-value on the v2 wire.

reason: String

Why the capability is unavailable.



Withheld

A value exists but its plaintext is deliberately not transported.

Fields

reason: String

Policy or sensitivity reason for withholding plaintext.

sensitivity: SemanticValueSensitivity

Sensitivity of the omitted value.