pub enum SemanticValueObservation {
Known {
value: String,
sensitivity: SemanticValueSensitivity,
evidence: EvidenceProvenance,
},
Absent {
reason: String,
evidence: EvidenceProvenance,
},
Unknown {
reason: String,
},
Unsupported {
capability: String,
reason: String,
},
Withheld {
reason: String,
sensitivity: SemanticValueSensitivity,
},
}Expand description
A semantic value with absence, support and confidentiality preserved.
Variants
Known
The value is known for this committed revision.
Fields

sensitivity: SemanticValueSensitivityApplication-declared artifact sensitivity.

evidence: EvidenceProvenanceSource proving this value for the committed revision.
Absent
The node authoritatively has no value now.
Fields

evidence: EvidenceProvenanceAuthoritative source proving absence.
Unknown
A later paired revision may provide the value.
Unsupported
The frozen contract cannot provide semantic values.
Fields
Withheld
A value exists but its plaintext is deliberately not transported.
Fields

sensitivity: SemanticValueSensitivitySensitivity of the omitted value.